package com.compdfkit.demo.annotation;

import android.os.Bundle;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;

import com.compdfkit.demo.annotation.databinding.ActivityMainBinding;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;
import com.compdfkit.tools.annotation.pdfproperties.pdfattr.CAnnotAttr;
import com.compdfkit.tools.common.utils.task.CExtractAssetFileTask;
import com.compdfkit.tools.common.views.pdfbota.CPDFBOTA;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaDialogFragment;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaFragmentTabs;

public class MainActivity extends AppCompatActivity {

    /**
     * assets folder pdf file
     */
    public static final String QUICK_START_GUIDE = "Quick Start Guide V2.4.0.pdf";

    private ActivityMainBinding binding;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        //Extract PDF files from the Android assets folder
        CExtractAssetFileTask.extract(this, QUICK_START_GUIDE, QUICK_START_GUIDE, (filePath) -> binding.pdfView.openPDF(filePath));
        binding.annotationToolBar.initWithPDFView(binding.pdfView);
        binding.annotationToolBar.setFragmentManager(getSupportFragmentManager());
        initAnnotationAttributes();
        initListener();
    }
    private void initListener(){
        binding.pdfToolBar.setBoTaBtnClickListener(v -> {
            CPDFBotaDialogFragment dialogFragment = CPDFBotaDialogFragment.newInstance();
            dialogFragment.initWithPDFView(binding.pdfView);
            CPDFBotaFragmentTabs annotationTab = new CPDFBotaFragmentTabs(CPDFBOTA.ANNOTATION, "Annotations");
            dialogFragment.setBotaDialogTab(annotationTab);
            dialogFragment.show(getSupportFragmentManager(), "annotationList");
        });
    }


    private void initAnnotationAttributes() {
        int defaultColor = ContextCompat.getColor(this, R.color.tools_annotation_markup_default_color);

        new CAnnotAttr.Builder(binding.pdfView)
                .setMarkup(CAnnotationType.HIGHLIGHT, defaultColor, 255)
                .setMarkup(CAnnotationType.UNDERLINE, defaultColor, 255)
                .setMarkup(CAnnotationType.SQUIGGLY, defaultColor, 255)
                .setMarkup(CAnnotationType.STRIKEOUT, defaultColor, 255)
                .setShape(CAnnotationType.SQUARE, defaultColor, 255, defaultColor, 255, 5)
                .setShape(CAnnotationType.CIRCLE, defaultColor, 255, defaultColor, 255, 5)
                .setShape(CAnnotationType.LINE, defaultColor, 255, defaultColor, 255, 5)
                .setInkAttribute(defaultColor, 255)
                .init();
    }
}