package com.compdfkit.tools.annotation.pdfproperties;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.viewpager2.widget.ViewPager2;

import com.compdfkit.tools.R;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.adapter.CAnnotPropertiesFragmentAdapter;
import com.compdfkit.tools.annotation.pdfproperties.pdfattr.CAnnotStyle;
import com.compdfkit.tools.common.views.CToolBar;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;

import java.util.ArrayList;
import java.util.List;


public class CAnnotStyleDialogFragment extends BottomSheetDialogFragment {


    private CToolBar toolBar;

    private ViewPager2 viewPager;

    private CAnnotStyle style;

    public static CAnnotStyleDialogFragment newInstance(CAnnotStyle style){
        CAnnotStyleDialogFragment dialogFragment = new CAnnotStyleDialogFragment();
        dialogFragment.setStyle(style);
        return dialogFragment;
    }

    public void setStyle(CAnnotStyle style){
        this.style = style;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setStyle(STYLE_NORMAL, R.style.Tools_Base_Theme_BottomSheetDialogStyle);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_annot_style_dialog_fragment, container, false);
        toolBar = rootView.findViewById(R.id.tool_bar);
        viewPager = rootView.findViewById(R.id.view_pager);
        return rootView;
    }


    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        if (style != null) {
            toolBar.setTitle(style.getAnnotTypeTitle(getContext()));
        }
        toolBar.setOnClickListener(v -> {
            dismiss();
        });
        initViewPager();
    }

    private void initViewPager(){
        if (style != null){
            CAnnotPropertiesFragmentAdapter adapter = new CAnnotPropertiesFragmentAdapter(style, getChildFragmentManager(), getLifecycle());
            viewPager.setAdapter(adapter);
            viewPager.setUserInputEnabled(false);
        }
    }

    @Override
    public void onSaveInstanceState(@NonNull Bundle outState) {
        outState.putParcelable("extra_annot_style", style);
        super.onSaveInstanceState(outState);
    }

}
