/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.data;

import com.compdfkit.tools.annotation.pdfproperties.pdfattr.CAnnotStyle;
import com.compdfkit.tools.annotation.pdfproperties.pdfmarkup.CMarkupStyleFragment;
import com.compdfkit.tools.common.views.pdfproperties.basic.CBasicPropertiesFragment;

import java.util.ArrayList;
import java.util.List;


public class CPropertiesFragmentFactory {


    public static List<Class<? extends CBasicPropertiesFragment>> getPropertiesFragmentClass(CAnnotStyle style) {
        List<Class<? extends CBasicPropertiesFragment>> list = new ArrayList<>();
        switch (style.getType()) {
            case STRIKEOUT:
            case HIGHLIGHT:
            case UNDERLINE:
            case SQUIGGLY:
                list.addAll(markupFragments());
                break;
            default:
               break;
        }
        return list;
    }

    public static <T extends CBasicPropertiesFragment> CBasicPropertiesFragment createPropertiesFragment(Class<T> tClass, CAnnotStyle style){
        try{
            CBasicPropertiesFragment fragment = tClass.getDeclaredConstructor().newInstance();
            fragment.setStyle(style);
            return fragment;
        }catch (Exception e){
            return null;
        }
    }


    private static List<Class<? extends CBasicPropertiesFragment>> markupFragments() {
        List<Class<? extends CBasicPropertiesFragment>> list = new ArrayList<>();
        list.add(CMarkupStyleFragment.class);
        return list;
    }

}
