package com.compdfkit.tools.annotation.pdfproperties.pdfattr;

import androidx.annotation.ColorInt;
import androidx.annotation.IntRange;

import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;
import com.compdfkit.tools.common.views.pdfview.CPDFViewCtrl;
import com.compdfkit.ui.attribute.CPDFAnnotAttribute;
import com.compdfkit.ui.attribute.CPDFHighlightAttr;
import com.compdfkit.ui.attribute.CPDFSquigglyAttr;
import com.compdfkit.ui.attribute.CPDFStrikeoutAttr;
import com.compdfkit.ui.attribute.CPDFUnderlineAttr;
import com.compdfkit.ui.attribute.IAttributeCallback;

import java.util.HashMap;

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2023/4/21
 * description:
 */
public class CAnnotAttr {

    private HashMap<CAnnotationType, CAnnotStyle> attrMaps = new HashMap<>();

    private CPDFViewCtrl pdfView;

    private boolean store;

    public void apply(){
        CPDFAnnotAttribute attribute = pdfView.getCPdfReaderView().getReaderAttribute().getAnnotAttribute();
        for (CAnnotationType type : attrMaps.keySet()) {
            CAnnotStyle params = attrMaps.get(type);
            if (params == null){
                continue;
            }
            IAttributeCallback callback = null;
            switch (params.getType()) {
                case HIGHLIGHT:
                    CPDFHighlightAttr highlightAttr = attribute.getHighlightAttr();
                    highlightAttr.setColor(params.getColor());
                    highlightAttr.setAlpha(params.getColorAlpha());
                    callback = highlightAttr;
                    break;

                case UNDERLINE:
                    CPDFUnderlineAttr underlineAttr = attribute.getUnderlineAttr();
                    underlineAttr.setColor(params.getColor());
                    underlineAttr.setAlpha(params.getColorAlpha());
                    callback = underlineAttr;
                    break;

                case SQUIGGLY:
                    CPDFSquigglyAttr squigglyAttr = attribute.getSquigglyAttr();
                    squigglyAttr.setColor(params.getColor());
                    squigglyAttr.setAlpha(params.getColorAlpha());
                    callback = squigglyAttr;
                    break;

                case STRIKEOUT:
                    CPDFStrikeoutAttr strikeoutAttr= attribute.getStrikeoutAttr();
                    strikeoutAttr.setColor(params.getColor());
                    strikeoutAttr.setAlpha(params.getColorAlpha());
                    callback = strikeoutAttr;
                    break;
                default:
                    break;
            }
            if (store){
                if (callback != null) {
                    callback.onstore();
                }
            }
        }
    }



    public static class Builder {
        private HashMap<CAnnotationType, CAnnotStyle> attrMaps = new HashMap<>();

        private CPDFViewCtrl pdfView;

        public Builder(CPDFViewCtrl pdfView) {
            this.pdfView = pdfView;
        }

        public Builder setMarkup(CAnnotationType type, @ColorInt int color, @IntRange(from = 0, to = 255) int colorAlpha) {
            CAnnotStyle params = new CAnnotStyle(type);
            params.setColor(color);
            params.setColorAlpha(colorAlpha);
            attrMaps.put(type, params);
            return this;
        }


        public Builder setInkAttribute(@ColorInt int color, @IntRange(from = 0, to = 255) int colorAlpha) {
            CAnnotStyle style = new CAnnotStyle(CAnnotationType.INK);
            style.setColor(color);
            style.setColorAlpha(colorAlpha);
            attrMaps.put(CAnnotationType.INK, style);
            return this;
        }

        public Builder setShape(CAnnotationType type,
                                @ColorInt int lineColor,
                                @IntRange(from = 0, to = 255) int lineColorAlpha,
                                @ColorInt int fillColor,
                                @IntRange(from = 0, to = 255) int fillColorAlpha,
                                float borderWidth) {
            CAnnotStyle params = new CAnnotStyle(type);
            params.setLineColor(lineColor);
            params.setLineColorAlpha(lineColorAlpha);
            params.setFillColor( fillColor);
            params.setFillColor(fillColorAlpha);
            params.setBorderWidth(borderWidth);
            attrMaps.put(type, params);
            return this;
        }

        private CAnnotAttr create(){
            CAnnotAttr annotationAttr = new CAnnotAttr();
            annotationAttr.attrMaps = attrMaps;
            annotationAttr.pdfView = pdfView;
            return annotationAttr;
        }

        public void apply(){
            create().apply();
        }

        public void onStore(){
            CAnnotAttr annotationAttr = create();
            annotationAttr.store = true;
            annotationAttr.apply();
        }

        public void init(){
            onStore();
        }
    }

}
