/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.utils.animation;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ObjectAnimator;
import android.animation.PropertyValuesHolder;
import android.view.View;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.LinearInterpolator;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;


public class CFillScreenManager {

    public static final long CONFIG_SHORT_ANIM_TIME = 300L;

    private List<View> topToolViewList = new ArrayList<>();
    private List<View> bottomToolViewList = new ArrayList<>();

    public void showFromTop(View view, long duration) {
        if (view.getVisibility() == android.view.View.VISIBLE) {
            return;
        }
        if (!view.isHardwareAccelerated()) {
            view.setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        view.setAlpha(0F);
        view.setVisibility(View.VISIBLE);
        view.animate()
                .alpha(1f)
                .translationY(0f)
                .setInterpolator(new AccelerateInterpolator())
                .setDuration(duration)
                .setListener(new AnimatorListenerAdapter() {
                    @Override
                    public void onAnimationEnd(Animator animation) {
                        super.onAnimationEnd(animation);
                        animation.removeListener(this);
                        view.setLayerType(View.LAYER_TYPE_NONE, null);
                        view.clearAnimation();
                    }
                });
    }

    public void hideFromTop(View view, long duration) {
        if (view.getVisibility() != android.view.View.VISIBLE) {
            return;
        }
        if (!view.isHardwareAccelerated()) {
            view.setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        view.animate()
                .alpha(0.0f)
                .translationY(-1.0f * view.getHeight())
                .setInterpolator(new AccelerateInterpolator())
                .setDuration(duration)
                .setListener(new AnimatorListenerAdapter() {
                    @Override
                    public void onAnimationEnd(Animator animation) {
                        super.onAnimationEnd(animation);
                        animation.removeListener(this);
                        view.setLayerType(View.LAYER_TYPE_NONE, null);
                        view.clearAnimation();
                        view.setVisibility(View.GONE);
                    }
                });
    }

    public void showFromBottom(View view, long duration) {
        if (view.getVisibility() == android.view.View.VISIBLE) {
            return;
        }
        if (!view.isHardwareAccelerated()) {
            view.setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        view.setAlpha(0F);
        view.setVisibility(View.VISIBLE);
        view.animate()
                .alpha(1f)
                .translationY(0f)
                .setInterpolator(new AccelerateInterpolator())
                .setDuration(duration)
                .setListener(new AnimatorListenerAdapter() {
                    @Override
                    public void onAnimationEnd(Animator animation) {
                        super.onAnimationEnd(animation);
                        animation.removeListener(this);
                        view.setLayerType(View.LAYER_TYPE_NONE, null);
                        view.clearAnimation();
                    }
                });
    }

    public void hideFromBottom(View view, long duration) {
        if (view.getVisibility() != android.view.View.VISIBLE) {
            return;
        }
        if (!view.isHardwareAccelerated()) {
            view.setLayerType(View.LAYER_TYPE_HARDWARE, null);
        }
        view.animate()
                .alpha(0.0f)
                .translationY((float) view.getHeight())
                .setInterpolator(new AccelerateInterpolator())
                .setDuration(duration)
                .setListener(new AnimatorListenerAdapter() {
                    @Override
                    public void onAnimationEnd(Animator animation) {
                        super.onAnimationEnd(animation);
                        animation.removeListener(this);
                        view.setLayerType(View.LAYER_TYPE_NONE, null);
                        view.clearAnimation();
                        view.setVisibility(View.GONE);
                    }
                });
    }



    public void bindTopToolView(View... topToolView) {
        topToolViewList.addAll(Arrays.asList(topToolView));
    }

    public void bindBottomToolViewList(View... bottomToolView) {
        bottomToolViewList.addAll(Arrays.asList(bottomToolView));
    }


    public void fillScreenChange(boolean fillScreen) {
        if (fillScreen) {
            for (View view : topToolViewList) {
                hideFromTop(view, CONFIG_SHORT_ANIM_TIME);
            }
            for (View view : bottomToolViewList) {
                hideFromBottom(view, CONFIG_SHORT_ANIM_TIME);
            }
        } else {
            for (View view : topToolViewList) {
                showFromTop(view, CONFIG_SHORT_ANIM_TIME);
            }
            for (View view : bottomToolViewList) {
                showFromBottom(view, CONFIG_SHORT_ANIM_TIME);
            }
        }
    }
}
