/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfannotationbar;


import android.content.Context;
import android.util.AttributeSet;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.fragment.app.FragmentManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.core.annotation.CPDFAnnotation;
import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfannotationbar.adapter.CPDFAnnotationToolListAdapter;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotToolBean;
import com.compdfkit.tools.common.views.pdfannotationbar.data.CAnnotationToolDatas;
import com.compdfkit.tools.annotation.pdfproperties.CAnnotStyleDialogFragment;
import com.compdfkit.tools.annotation.pdfproperties.pdfattr.CAnnotStyle;
import com.compdfkit.tools.common.views.pdfview.CPDFViewCtrl;

public class CAnnotationToolbar extends FrameLayout {

    private RecyclerView rvAnnotationList;

    private AppCompatImageView ivSetting;

    private AppCompatImageView ivUndo;

    private AppCompatImageView ivRedo;

    private CPDFAnnotationToolListAdapter toolListAdapter;

    private CPDFViewCtrl pdfView;

    private FragmentManager fragmentManager;

    public CAnnotationToolbar(@NonNull Context context) {
        this(context, null);
    }

    public CAnnotationToolbar(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CAnnotationToolbar(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView(context);
    }

    private void initView(Context context){
        inflate(context, R.layout.tools_annot_tool_bar, this);
        rvAnnotationList = findViewById(R.id.rv_annotation);
        ivSetting = findViewById(R.id.iv_annotation_attr_settings);
        ivUndo = findViewById(R.id.iv_annotation_attr_undo);
        ivRedo = findViewById(R.id.iv_annotation_attr_redo);
        toolListAdapter = new CPDFAnnotationToolListAdapter();
        toolListAdapter.setList(CAnnotationToolDatas.getAnnotationList());

        rvAnnotationList.setLayoutManager(new LinearLayoutManager(getContext(), LinearLayoutManager.HORIZONTAL, false));
        rvAnnotationList.setAdapter(toolListAdapter);
        initListener();
    }

    private void initListener(){
        ivSetting.setOnClickListener(v -> {
            CAnnotStyle style = new CAnnotStyle(toolListAdapter.getCurrentAnnotType());
            CAnnotStyleDialogFragment dialogFragment = CAnnotStyleDialogFragment.newInstance(style);
            dialogFragment.show(fragmentManager, "annotStyleDialogFragment");
        });
        ivUndo.setOnClickListener(v -> {

        });
        ivRedo.setOnClickListener(v -> {

        });
        toolListAdapter.setOnItemClickListener((adapter, view, position) -> {
            CAnnotToolBean bean = adapter.list.get(position);
            toolListAdapter.selectItem(position);
            switchAnnotationType(bean);
        });
    }

    public void initWithPDFView(CPDFViewCtrl pdfView){
        this.pdfView = pdfView;
    }

    public void setFragmentManager(FragmentManager fragmentManager) {
        this.fragmentManager = fragmentManager;
    }

    private void switchAnnotationType(CAnnotToolBean bean){
        if (!bean.isSelect()){
            pdfView.resetAnnotationType();
            return;
        }
        switch (bean.getType()){
            case NOTE:
                pdfView.changeAnnotationType(CPDFAnnotation.Type.TEXT);
                break;
            case ARROW:
                pdfView.changeAnnotationType(CPDFAnnotation.Type.LINE);
                break;
            case SIGNATURE:
                pdfView.changeAnnotationType(CPDFAnnotation.Type.STAMP);
                break;
            case PIC:
                break;
            default:
                pdfView.changeAnnotationType(CPDFAnnotation.Type.valueOf(bean.getType().name()));
                break;
        }
    }


}
