/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfannotationbar.adapter;

import android.content.Context;
import android.view.ViewGroup;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotToolBean;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;
import com.compdfkit.tools.common.utils.adapter.CBaseQuickAdapter;
import com.compdfkit.tools.common.utils.adapter.CBaseQuickViewHolder;

import java.util.List;


public class CPDFAnnotationToolListAdapter extends CBaseQuickAdapter<CAnnotToolBean, CBaseQuickViewHolder> {

    public static final String REFRESH_SELECT = "refresh_select";

    @Override
    protected CBaseQuickViewHolder onCreateViewHolder(Context context, ViewGroup parent, int viewType) {
        return new CBaseQuickViewHolder(R.layout.tools_annot_list_item, parent);
    }

    @Override
    protected void onBindViewHolder(CBaseQuickViewHolder holder, int position, CAnnotToolBean item) {
        holder.setImageResource(R.id.iv_annot_type, item.getIconResId());
        holder.setSelected(R.id.iv_annot_type, item.isSelect());
    }

    @Override
    protected void onBindViewHolder(CBaseQuickViewHolder holder, int position, CAnnotToolBean item, List<Object> payloads) {
        if (payloads.isEmpty()) {
           super.onBindViewHolder(holder, position, item, payloads);
        } else {
            for (Object payload : payloads) {
                if (payload == REFRESH_SELECT) {
                    holder.setSelected(R.id.iv_annot_type, item.isSelect());
                }
            }
        }
    }

    public void selectItem(int position) {
        for (int i = 0; i < list.size(); i++) {
            CAnnotToolBean item = list.get(i);
            if (i == position) {
                item.setSelect(!item.isSelect());
            } else {
                item.setSelect(false);
            }
            notifyItemChanged(i, REFRESH_SELECT);
        }
    }

    public CAnnotationType getCurrentAnnotType() {
        for (CAnnotToolBean cAnnotToolBean : list) {
            if (cAnnotToolBean.isSelect()){
                return cAnnotToolBean.getType();
            }
        }
        return CAnnotationType.UNKNOWN;
    }
}
