/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.colorlist;


import android.content.Context;
import android.content.res.TypedArray;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.widget.LinearLayout;

import androidx.annotation.ColorInt;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;

import java.util.ArrayList;
import java.util.List;

public class CColorListView extends LinearLayout {

    private boolean showColorPicker = true;

    private boolean showTitle;

    private String title;

    private List<CColorItemBean> colorList = new ArrayList<>();

    private int selectColor;

    private OnColorChangeListener colorChangeListener;
    private CColorListAdapter colorListAdapter;

    private int colorListResId = R.array.tools_annot_markup_colors;

    public CColorListView(Context context) {
        this(context, null);
    }

    public CColorListView(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CColorListView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initAttr(context, attrs);
        init(context);
    }

    private void initAttr(Context context, AttributeSet attributeSet){
        TypedArray typedArray = context.obtainStyledAttributes(attributeSet, R.styleable.CColorListView);
        if (typedArray != null) {
            showColorPicker = typedArray.getBoolean(R.styleable.CColorListView_tools_show_color_picker, true);
            colorListResId = typedArray.getResourceId(R.styleable.CColorListView_tools_color_list,R.array.tools_annot_markup_colors);
            colorList = getColorListByResId();
            showTitle = typedArray.getBoolean(R.styleable.CColorListView_tools_show_title, true);
            title = typedArray.getString(R.styleable.CColorListView_tools_title);
            typedArray.recycle();
        }
    }

    private void init(Context context){
        inflate(context, R.layout.tools_color_list_view_layout, this);
        RecyclerView rvColor = findViewById(R.id.rv_color);
        AppCompatTextView tvTitle = findViewById(R.id.tv_color_title);
        if (!showTitle){
            tvTitle.setVisibility(GONE);
        }
        if (!TextUtils.isEmpty(title)){
            tvTitle.setText(title);
        }
        colorListAdapter = new CColorListAdapter();
        colorListAdapter.setList(colorList);
        colorListAdapter.setOnItemClickListener((adapter, view, position) -> {
            CColorItemBean bean = adapter.list.get(position);
            if (bean.isColorPicker()){

            }else {
                colorListAdapter.selectItem(position);
                if (colorChangeListener != null) {
                    colorChangeListener.color(bean.getColor());
                }
            }
        });
        rvColor.setLayoutManager(new LinearLayoutManager(getContext(), LinearLayoutManager.HORIZONTAL, false));
        rvColor.setAdapter(colorListAdapter);
    }

    private List<CColorItemBean> getColorListByResId(){
        List<CColorItemBean> list = new ArrayList<>();
        if (colorListResId != -1){
            int[] colors = getResources().getIntArray(colorListResId);
            if (colors != null && colors.length >0){
                for (int color : colors) {
                    list.add(new CColorItemBean(color));
                }
            }
        }
        if (showColorPicker){
            list.add(CColorItemBean.colorPickerItem());
        }
        return list;
    }

    public void setSelectColor(@ColorInt int color){
        this.selectColor = color;
        if (colorListAdapter != null) {
            colorListAdapter.selectByColor(color);
        }
        if (colorChangeListener != null) {
            colorChangeListener.color(color);
        }
    }

    public void showColorPicker(boolean show){
        this.showColorPicker = show;
        if (colorListAdapter != null) {
            colorListAdapter.setList(getColorListByResId());
            setSelectColor(selectColor);
        }
    }

    public void setColorChangeListener(OnColorChangeListener colorChangeListener) {
        this.colorChangeListener = colorChangeListener;
    }

    public interface OnColorChangeListener {
        void color(@ColorInt int color);
    }
}
